@@ -25,10 +25,9 @@ class Line:
             self.admittance = 1/impedance
 
     def __str__(self) -> str:
-        Y = colored(complex_to_str(self.admittance), 'green')
-        I = colored(complex_to_str(self.amperage), 'green')
         S12 = colored(complex_to_str(self.power), 'green')
         S21 = colored(complex_to_str(self.power_reverse), 'green')
+        S = colored(complex_to_str(self.power + self.power_reverse), 'green')
         bar1 = colored(self.bar1.name, 'blue')
         bar2 = colored(self.bar2.name, 'blue')
-        return f'{bar1} ━━ {bar2}: Y = ({Y}), I = ({I}), S{bar1}{bar2} = ({S12}), S{bar2}{bar1} = ({S21})'
+        return f'{bar1} ━━ {bar2}: S = ({S}), S{bar1}{bar2} = ({S12}), S{bar2}{bar1} = ({S21})'
